---
title: Bugs & To Do
---

#### 2023-01-15

- [ ] fix publication data for consequent inclusion of `ISO3166alpha2` codes
- [ ] fix publications.py default filters "PMID" and "genomes:>0"
- [ ] create bycon documentation subdomain & configure Github pages for it  